==> ubuntustudio-default-settings_24.04.8.tar.xz: ubuntustudio-default-settings/usr/share/plasma/layout-templates/org.ubuntustudio.desktop.defaultPanel/contents/layout.js <==
var panel = new Panel
var panelScreen = panel.screen
var freeEdges = {"top": true, "bottom": true, "left": true, "right": true}

for (i = 0; i < panelIds.length; ++i) {
    var tmpPanel = panelById(panelIds[i])
    if (tmpPanel.screen == panelScreen) {
        // Ignore the new panel
        if (tmpPanel.id != panel.id) {
            freeEdges[tmpPanel.location] = false;
        }
    }
}

if (freeEdges["top"] == true) {
    panel.location = "top";
} else if (freeEdges["bottom"] == true) {
    panel.location = "bottom";
} else if (freeEdges["left"] == true) {
    panel.location = "left";
} else if (freeEdges["right"] == true) {
    panel.location = "right";
} else {
    // There is no free edge, so leave the default value
    panel.location = "top";
}

panel.height = gridUnit * 1.7

var kickoff = panel.addWidget("org.kde.plasma.kicker")
kicker.writeConfig("favoriteApps", "preferred://browser,org.kde.discover.desktop,systemsettings.desktop,org.kde.dolphin.desktop,org.kde.kate.desktop,patchance.desktop,ardour.desktop,com.obsproject.Studio.desktop,org.kde.krita.desktop,gimp.desktop,org.kde.kdenlive.desktop,org.kde.digikam.desktop,org.darktable.darktable.desktop")
kicker.writeConfig("showAppsByName", "true")
kicker.currentConfigGroup = ["Shortcuts"]
kicker.writeConfig("global", "Alt+F1")


//panel.addWidget("org.kde.plasma.showActivityManager")
panel.addWidget("org.kde.plasma.pager")

var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
var launcherlist = [ "preferred://browser",
                     "applications:patchance.desktop",
                     "applications:ardour.desktop",
                     "applications:com.obsproject.Studio.desktop",
                     "applications:org.kde.krita.desktop",
                     "applications:gimp.desktop",
                     "applications:org.kde.kdenlive.desktop",
                     "applications:org.kde.digikam.desktop",
                     "applications:org.darktable.darktable.desktop",
                     "applications:systemsettings.desktop" ]
taskmanager.writeConfig("launchers", launcherlist)

/* Next up is determining whether to add the Input Method Panel
 * widget to the panel or not. This is done based on whether
 * the system locale's language id is a member of the following
 * white list of languages which are known to pull in one of
 * our supported IME backends when chosen during installation
 * of common distributions. */

var langIds = ["as",    // Assamese
               "bn",    // Bengali
               "bo",    // Tibetan
               "brx",   // Bodo
               "doi",   // Dogri
               "gu",    // Gujarati
               "hi",    // Hindi
               "ja",    // Japanese
               "kn",    // Kannada
               "ko",    // Korean
               "kok",   // Konkani
               "ks",    // Kashmiri
               "lep",   // Lepcha
               "mai",   // Maithili
               "ml",    // Malayalam
               "mni",   // Manipuri
               "mr",    // Marathi
               "ne",    // Nepali
               "or",    // Odia
               "pa",    // Punjabi
               "sa",    // Sanskrit
               "sat",   // Santali
               "sd",    // Sindhi
               "si",    // Sinhala
               "ta",    // Tamil
               "te",    // Telugu
               "th",    // Thai
               "ur",    // Urdu
               "vi",    // Vietnamese
               "zh_CN", // Simplified Chinese
               "zh_TW"] // Traditional Chinese

if (langIds.indexOf(languageId) != -1) {
    panel.addWidget("org.kde.plasma.kimpanel");
}

panel.addWidget("org.kde.plasma.systemtray")
panel.addWidget("org.kde.plasma.digitalclock")
panel.addWidget("org.kde.plasma.minimizeall")

==> ubuntustudio-default-settings_24.04.26.tar.xz: ubuntustudio-default-settings/usr/share/plasma/layout-templates/org.ubuntustudio.desktop.defaultPanel/contents/layout.js <==
var panel = new Panel
var panelScreen = panel.screen
var freeEdges = {"top": true, "bottom": true, "left": true, "right": true}

for (i = 0; i < panelIds.length; ++i) {
    var tmpPanel = panelById(panelIds[i])
    if (tmpPanel.screen == panelScreen) {
        // Ignore the new panel
        if (tmpPanel.id != panel.id) {
            freeEdges[tmpPanel.location] = false;
        }
    }
}

if (freeEdges["top"] == true) {
    panel.location = "top";
} else if (freeEdges["bottom"] == true) {
    panel.location = "bottom";
} else if (freeEdges["left"] == true) {
    panel.location = "left";
} else if (freeEdges["right"] == true) {
    panel.location = "right";
} else {
    // There is no free edge, so leave the default value
    panel.location = "top";
}

panel.height = gridUnit * 1.7

var kicker = panel.addWidget("org.kde.plasma.kicker")
kicker.writeConfig("favoriteApps", "preferred://browser,org.kde.discover.desktop,systemsettings.desktop,org.kde.dolphin.desktop,org.kde.kate.desktop,patchance.desktop,ardour.desktop,com.obsproject.Studio.desktop,org.kde.krita.desktop,gimp.desktop,org.kde.kdenlive.desktop,org.kde.digikam.desktop,org.darktable.darktable.desktop")
kicker.writeConfig("showAppsByName", "true")
kicker.currentConfigGroup = ["Shortcuts"]
kicker.writeConfig("global", "Alt+F1")


//panel.addWidget("org.kde.plasma.showActivityManager")
panel.addWidget("org.kde.plasma.pager")

var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
var launcherlist = [ "preferred://browser",
                     "applications:patchance.desktop",
                     "applications:ardour.desktop",
                     "applications:com.obsproject.Studio.desktop",
                     "applications:org.kde.krita.desktop",
                     "applications:gimp.desktop",
                     "applications:org.kde.kdenlive.desktop",
                     "applications:org.kde.digikam.desktop",
                     "applications:org.darktable.darktable.desktop",
                     "applications:systemsettings.desktop" ]
taskmanager.writeConfig("launchers", launcherlist)

/* Next up is determining whether to add the Input Method Panel
 * widget to the panel or not. This is done based on whether
 * the system locale's language id is a member of the following
 * white list of languages which are known to pull in one of
 * our supported IME backends when chosen during installation
 * of common distributions. */

var langIds = ["as",    // Assamese
               "bn",    // Bengali
               "bo",    // Tibetan
               "brx",   // Bodo
               "doi",   // Dogri
               "gu",    // Gujarati
               "hi",    // Hindi
               "ja",    // Japanese
               "kn",    // Kannada
               "ko",    // Korean
               "kok",   // Konkani
               "ks",    // Kashmiri
               "lep",   // Lepcha
               "mai",   // Maithili
               "ml",    // Malayalam
               "mni",   // Manipuri
               "mr",    // Marathi
               "ne",    // Nepali
               "or",    // Odia
               "pa",    // Punjabi
               "sa",    // Sanskrit
               "sat",   // Santali
               "sd",    // Sindhi
               "si",    // Sinhala
               "ta",    // Tamil
               "te",    // Telugu
               "th",    // Thai
               "ur",    // Urdu
               "vi",    // Vietnamese
               "zh_CN", // Simplified Chinese
               "zh_TW"] // Traditional Chinese

if (langIds.indexOf(languageId) != -1) {
    panel.addWidget("org.kde.plasma.kimpanel");
}

panel.addWidget("org.kde.plasma.systemtray")
panel.addWidget("org.kde.plasma.digitalclock")
panel.addWidget("org.kde.plasma.minimizeall")
